=========================
HELPDESK CC AND TO TEXT
=========================

..
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! This file is generated by oca-gen-addon-readme !!
   !! changes will be overwritten.                   !!
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! source digest: sha256:fa88a5911e9d75e4ccaee78931e61a91ccfe34e0de09254e0edd30ad0752f428
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

.. |badge1| image:: https://img.shields.io/badge/maturity-Beta-yellow.png
    :target: https://odoo-community.org/page/development-status
    :alt: Beta
.. |badge2| image:: https://img.shields.io/badge/licence-AGPL--3-blue.png
    :target: http://www.gnu.org/licenses/agpl-3.0-standalone.html
    :alt: License: AGPL-3

|badge1| |badge2|

Add the CC and TO fields to the helpdesk.ticket model and fill these fields automatically when receiving an email.

**Table of contents**

.. contents::
   :local:

Configuration
=============

No configuration needed for this module.

Usage
=====

The helpdesk.ticket model contains the new CC and TO fields for the model.

Known issues / Roadmap
======================

There are no issues for the moment.

Bug Tracker
===========

Bugs are tracked on `GitLab Issues <https://gitlab.com/somitcoop/erp-research/odoo-helpdesk/-/issues>`_.
In case of trouble, please check there if your issue has already been reported.
If you spotted it first, help us smashing it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

Credits
=======

Authors
~~~~~~~

* SomIT SCCL
* Som Connexio SCCL


Contributors
~~~~~~~~~~~~

* `SomIT SCCL <https://somit.coop>`_:

    * Álvaro García <alvaro.garcia@somit.coop>
    * José Robles <jose.robles@somit.coop>


* `Som Connexio SCCL <https://somconnexio.coop>`_:

    * Gerard Funosas <gerard.funosas@somconnexio.coop>


Maintainers
~~~~~~~~~~~

This module is maintained by the OCA.

.. image:: https://odoo-community.org/logo.png
   :alt: Odoo Community Association
   :target: https://odoo-community.org

OCA, or the Odoo Community Association, is a nonprofit organization whose
mission is to support the collaborative development of Odoo features and
promote its widespread use.

You are welcome to contribute. To learn how please visit https://odoo-community.org/page/Contribute.